/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ambari.server.state.quicklinksprofile;


import java.util.Optional;

import javax.annotation.Nonnull;

import org.apache.ambari.server.state.quicklinks.Link;


public interface QuickLinkVisibilityController {

  /**
   * @param service The name of the service the quicklink belongs to
   * @param quickLink the link
   * @return a boolean indicating if the link should be visible
   */
  boolean isVisible(@Nonnull String service, @Nonnull Link quickLink);

  /**
   * @param service The name of the service the quicklink belongs to
   * @param quickLink the link
   * @return An optional url override for this link
   */
  Optional<String> getUrlOverride(@Nonnull String service, @Nonnull Link quickLink);

}

